<?php

use WooCommerce\PayPalCommerce\Subscription\Helper\SubscriptionHelper;
use WooCommerce\PayPalCommerce\WcGateway\Settings\Settings;
use WooCommerce\PayPalCommerce\Button\Helper\MessagesApply;
use WooCommerce\PayPalCommerce\WcGateway\Gateway\PayPalGateway;
use WooCommerce\PayPalCommerce\Button\Endpoint\DataClientIdEndpoint;

use WooCommerce\PayPalCommerce\Button\Endpoint\ChangeCartEndpoint;
use WooCommerce\PayPalCommerce\Button\Endpoint\CreateOrderEndpoint;
use WooCommerce\PayPalCommerce\Button\Endpoint\ApproveOrderEndpoint;
use WooCommerce\PayPalCommerce\Button\Endpoint\StartPayPalVaultingEndpoint;
use WooCommerce\PayPalCommerce\Button\Endpoint\SaveCheckoutFormEndpoint;
use WooCommerce\PayPalCommerce\Button\Endpoint\ValidateCheckoutEndpoint;
use WooCommerce\PayPalCommerce\Button\Endpoint\CartScriptParamsEndpoint;
use WooCommerce\PayPalCommerce\WcGateway\Gateway\CardButtonGateway;
use WooCommerce\PayPalCommerce\Onboarding\Environment;
use WooCommerce\PayPalCommerce\Subscription\FreeTrialHandlerTrait;

use WooCommerce\PayPalCommerce\ApiClient\Endpoint\WC_Customer;
use WooCommerce\PayPalCommerce\Subscription\WC_Product;
use WooCommerce\PayPalCommerce\Subscription\WC_Subscriptions_Product;
use Psr\Container\ContainerInterface;
use WooCommerce\PayPalCommerce\ApiClient;


if (is_plugin_active('woocommerce-paypal-payments/woocommerce-paypal-payments.php')) {
    // $settings = get_option( 'woocommerce-ppcp-settings', array() );
    // var_dump($settings);

    // die();

    function payerData() {
        $customer = WC()->customer;
        if ( ! is_user_logged_in() || ! ( $customer instanceof \WC_Customer ) ) {
            return null;
        }
        return $customer;
    }

    function bn_codes(): array {
        return array(
            'checkout'  => 'Woo_PPCP',
            'cart'      => 'Woo_PPCP',
            'mini-cart' => 'Woo_PPCP',
            'product'   => 'Woo_PPCP',
        );
    }

    function attributes(): array {
        return array(
            'data-partner-attribution-id' => 'Woo_PPCP' 
        );
    }

    function context(): string {
        $context = 'checkout';
        // if ( is_product() || wc_post_content_has_shortcode( 'product_page' ) ) {
        //     $context = 'product';
        // }
        // if ( is_cart() ) {
        //     $context = 'cart';
        // }
        // if ( is_checkout() && !  is_paypal_continuation() ) {
        //     $context = 'checkout';
        // }
        if ( is_checkout_pay_page() ) {
            $context = 'pay-now';
        }
        return $context;
    }

    function load_button_component() : bool {
        $load_buttons = true;
        return $load_buttons;
    }

    function dcc_is_enabled(): bool {
        $settings = get_option( 'woocommerce-ppcp-settings', array() );
        $keys = array(
            'client_id',
            'client_secret'
        );
        foreach ( $keys as $key ) {
            if ( !$settings[$key] ) {
                return false;
            }
        }

        return true;
    }

    function components(): array {
        $store_raw_country = get_option( 'woocommerce_default_country' );
        $split_country = explode( ":", $store_raw_country );
        $store_country = $split_country[0];
        $messages_apply = new MessagesApply($store_country);

        $components = array();

        if (load_button_component()) {
            $components[] = 'buttons';
            $components[] = 'funding-eligibility';
        }
        if ($messages_apply->for_country()) {
            $components[] = 'messages';
        }
        if ( dcc_is_enabled() ) {
            $components[] = 'hosted-fields';
        }
        return $components;
    }

    function can_save_vault_token(): bool {
        $settings = get_option( 'woocommerce-ppcp-settings', array() );

        if ( ! $settings['client_id' ]) {
            return false;
        }
        // isset($settings['vault_enabled']) ? $settings['vault_enabled'] : '' 
        if ( in_array('vault_enabled', $settings ) ) {
            return false;
        }
        return true;
    }

    function has_subscriptions(): bool {
        $default_button_locations = array(
            'smart_button_locations' => 'checkout'
        );
        $sub_settings = new Settings($default_button_locations);
        $subscription_helper = new SubscriptionHelper($sub_settings);

        if ( ! $subscription_helper->accept_only_automatic_payment_gateways() ) {
            return false;
        }
        if ( is_product() ) {
            return $subscription_helper->current_product_is_subscription();
        }
        if ( is_wc_endpoint_url( 'order-pay' ) ) {
            return $subscription_helper->order_pay_contains_subscription();
        }

        return $subscription_helper->cart_contains_subscription();

    }

    function is_wcs_plugin_active(): bool {
        return class_exists( WC_Subscriptions::class );
    }

    function is_free_trial_cart(): bool {
        if ( ! is_wcs_plugin_active() ) {
            return false;
        }

        $cart = WC()->cart;
        if ( ! $cart || $cart->is_empty() || (float) $cart->get_total( 'numeric' ) > 0 ) {
            return false;
        }

        foreach ( $cart->get_cart() as $item ) {
            $product = $item['data'] ?? null;
            if ( ! $product instanceof WC_Product ) {
                continue;
            }
            if ( WC_Subscriptions_Product::get_trial_length( $product ) > 0 ) {
                return true;
            }
        }

        return false;
    }
    
    function url_params() : array  {

        $default_button_locations = array(
            'smart_button_locations' => 'checkout'
        );
        $settings = get_option( 'woocommerce-ppcp-settings');
        $sub_settings = new Settings($default_button_locations);

        $subscription_helper = new SubscriptionHelper($sub_settings);

        $intent               = ( isset($settings['intent']) );
        $product_intent       = $subscription_helper->current_product_is_subscription() ? 'authorize' : $intent;
        $other_context_intent = $subscription_helper->cart_contains_subscription() ? 'authorize' : $intent;

        $params = array(
            'client-id'        => $settings['client_id'],
            'currency'         => get_woocommerce_currency(),
            'integration-date' => PAYPAL_INTEGRATION_DATE,
            'components'       => implode( ',', components() ),
            'vault'            => can_save_vault_token() ? 'true' : 'false',
            'commit'           => 'true',
            'intent'           => context() === 'product' ? $product_intent : $other_context_intent,
        );

        if (Environment::SANDBOX
            && defined( 'WP_DEBUG' ) && \WP_DEBUG && is_user_logged_in()
            && WC()->customer instanceof \WC_Customer && WC()->customer->get_billing_country()
            && 2 === strlen( WC()->customer->get_billing_country() )
        ) {
            $params['buyer-country'] = WC()->customer->get_billing_country();
        }

        $disable_funding = $settings['disable_funding'];

        // if ( ! is_checkout() ) {
        //     $disable_funding[] = 'card';
        // }

        $is_dcc_enabled = false;

        $available_gateways       = WC()->payment_gateways->get_available_payment_gateways();
        $is_separate_card_enabled = isset( $available_gateways[ CardButtonGateway::ID ] );

        if ( is_checkout() && ( $is_dcc_enabled || $is_separate_card_enabled ) ) {
            $key = array_search( 'card', $disable_funding, true );
            if ( false !== $key ) {
                unset( $disable_funding[ $key ] );
            }
        }

        $totalall_sources = static function( ContainerInterface $settings ) : string { 
            $settings['wcgateway.all-funding-sources'];
        };

        if ( is_free_trial_cart() ) {
            $all_sources = array_keys($totalall_sources);
            if ( $is_dcc_enabled || $is_separate_card_enabled ) {
                $all_sources = array_diff( $all_sources, array( 'card' ) );
            }
            $disable_funding = $all_sources;
        }

        if ( count( $disable_funding ) > 0 ) {
            $params['disable-funding'] = implode( ',', array_unique( $disable_funding ) );
        }
        
        $enable_funding = array( 'venmo' );
        if ( $settings['pay_later_messaging_enabled'] || ! in_array( 'credit', $disable_funding, true ) ) {
            $enable_funding[] = 'paylater';
        }

        if ( is_free_trial_cart() ) {
            $enable_funding = array();
        }

        if ( count( $enable_funding ) > 0 ) {
            $params['enable-funding'] = implode( ',', array_unique( $enable_funding ) );
        }

        // $smart_button_url = add_query_arg( $params, 'https://www.paypal.com/sdk/js' );
        return $params;
    }

    function localize_script(): array {
        global $wp;

        $url_params = url_params();

        $settings = get_option( 'woocommerce-ppcp-settings', array() );
        
            $localize = array(
                'url'                   => add_query_arg( $url_params, 'https://www.paypal.com/sdk/js' ),
                'url_params'            => $url_params,
                'script_attributes'     => attributes(),
                'data_client_id'        => array(
                    'set_attribute'         => ( is_checkout() && dcc_is_enabled() ) || can_save_vault_token(),
                    'endpoint'              => \WC_AJAX::get_endpoint( DataClientIdEndpoint::ENDPOINT ),
                    'nonce'                 => wp_create_nonce( DataClientIdEndpoint::nonce() ),
                    'user'                  => get_current_user_id(),
                    'has_subscriptions'     => has_subscriptions(),
                ),
                'redirect'                          => wc_get_checkout_url(),
                'context'                           => "checkout",
                'ajax'                              => array(
                    'change_cart'   => array(
                        'endpoint' => \WC_AJAX::get_endpoint( ChangeCartEndpoint::ENDPOINT ),
                        'nonce'    => wp_create_nonce( ChangeCartEndpoint::nonce() ),
                    ),
                    'create_order'  => array(
                        'endpoint' => \WC_AJAX::get_endpoint( CreateOrderEndpoint::ENDPOINT ),
                        'nonce'    => wp_create_nonce( CreateOrderEndpoint::nonce() ),
                    ),
                    'approve_order' => array(
                        'endpoint' => \WC_AJAX::get_endpoint( ApproveOrderEndpoint::ENDPOINT ),
                        'nonce'    => wp_create_nonce( ApproveOrderEndpoint::nonce() ),
                    ),
                    'vault_paypal'  => array(
                        'endpoint' => \WC_AJAX::get_endpoint( StartPayPalVaultingEndpoint::ENDPOINT ),
                        'nonce'    => wp_create_nonce( StartPayPalVaultingEndpoint::nonce() ),
                    ),
                    'save_checkout_form' => array(
                        'endpoint' => \WC_AJAX::get_endpoint( SaveCheckoutFormEndpoint::ENDPOINT ),
                        'nonce'    => wp_create_nonce( SaveCheckoutFormEndpoint::nonce() ),
                    ),
                    'validate_checkout'  => array(
                        'endpoint' => \WC_AJAX::get_endpoint( ValidateCheckoutEndpoint::ENDPOINT ),
                        'nonce'    => wp_create_nonce( ValidateCheckoutEndpoint::nonce() ),
                    ),
                    'cart_script_params' => array(
                        'endpoint' => \WC_AJAX::get_endpoint( CartScriptParamsEndpoint::ENDPOINT ),
                    ),
                ),
                'enforce_vault'                     => '',
                'can_save_vault_token'              => '',
                'is_free_trial_cart'                => '',
                'vaulted_paypal_email'              => '',
                'bn_codes'                          => bn_codes(),
                'payer'                             => payerData(),
                'button'                            => array(
                    'wrapper'           => '#ppc-button-' . PayPalGateway::ID,
                    'mini_cart_wrapper' => '#ppc-button-minicart',
                    'cancel_wrapper'    => '#ppcp-cancel',
                    'mini_cart_style' => array(
                        'layout'  => isset($settings['button_mini-cart_layout']) ? $settings['button_mini-cart_layout'] : '',
                        'color'   => isset($settings['button_mini-cart_color']) ? $settings['button_mini-cart_color'] : '',
                        'shape'   => isset($settings['button_mini-cart_shape']) ? $settings['button_mini-cart_shape'] : '',
                        'label'   => isset($settings['button_mini-cart_label']) ? $settings['button_mini-cart_label'] : '',
                        'tagline' => isset($settings['button_mini-cart_tagline']) ? $settings['button_mini-cart_tagline'] : '',
                        'height'  => isset($settings['button_mini-cart_height']) ? $settings['button_mini-cart_height'] : '',
                    ),
                    'style'             => array(
                        'layout'  => isset($settings['button_layout']) ? $settings['button_layout'] : '',
                        'color'   => isset($settings['button_color']) ? $settings['button_color'] : '',
                        'shape'   => isset($settings['button_shape']) ? $settings['button_shape'] : '',
                        'label'   => isset($settings['button_label']) ? $settings['button_label'] : '',
                        'tagline' => isset($settings['button_tagline']) ? $settings['button_tagline'] : '',
                    ),
                ),
                'separate_buttons'                  => array(
                    'card' => array(
                        'id'      => CardButtonGateway::ID,
                        'wrapper' => '#ppc-button-' . CardButtonGateway::ID,
                        'style'   => array(
                            'shape' => 'rect',
                            // TODO: color black, white from the gateway settings.
                        ),
                    ),
                ),
                'hosted_fields'                     => array(
                    'wrapper'     => '#ppcp-hosted-fields',
                    'labels'      => array(
                        'credit_card_number'       => '',
                        'cvv'                      => '',
                        'mm_yy'                    => __( 'MM/YY', 'woocommerce-paypal-payments' ),
                        'fields_not_valid'         => __(
                            'Unfortunately, your credit card details are not valid.',
                            'woocommerce-paypal-payments'
                        ),
                        'card_not_supported'       => __(
                            'Unfortunately, we do not support your credit card.',
                            'woocommerce-paypal-payments'
                        ),
                        'cardholder_name_required' => __( 'Cardholder\'s first and last name are required, please fill the checkout form required fields.', 'woocommerce-paypal-payments' ),
                    ),
                    'valid_cards' => ["mastercard", "visa", "amex", "discover", "american-express", "master-card"],
                    'contingency' => "SCA_WHEN_REQUIRED",
                ),
                'messages'                          => [],
                'labels'                            => array(
                    'error'          => array(
                        'generic'  => __(
                            'Something went wrong. Please try again or choose another payment source.',
                            'woocommerce-paypal-payments'
                        ),
                        'required' => array(
                            'generic'  => __(
                                'Required form fields are not filled.',
                                'woocommerce-paypal-payments'
                            ),
                            // phpcs:ignore WordPress.WP.I18n
                            'field'    => __( '%s is a required field.', 'woocommerce' ),
                            'elements' => array(  // Map <form element name> => text for error messages.
                                'terms' => __(
                                    'Please read and accept the terms and conditions to proceed with your order.',
                                    // phpcs:ignore WordPress.WP.I18n.TextDomainMismatch
                                    'woocommerce'
                                ),
                            ),
                        ),
                    ),
                    // phpcs:ignore WordPress.WP.I18n
                    'billing_field'  => _x( 'Billing %s', 'checkout-validation', 'woocommerce' ),
                    // phpcs:ignore WordPress.WP.I18n
                    'shipping_field' => _x( 'Shipping %s', 'checkout-validation', 'woocommerce' ),
                ),
                'order_id'                          => 'pay-now' === context() ? absint( $wp->query_vars['order-pay']) : 0 ,
                'single_product_buttons_enabled'    => '',
                'mini_cart_buttons_enabled'         => '',
                'basic_checkout_validation_enabled' => '1',
                'is_checkout' => 'yes'
            );
        return $localize;
    }

    $settings = get_option( 'woocommerce-ppcp-settings', array() );
    
    if (isset($settings['client_id'])  && !empty($settings['client_id'])) {
        add_action('wp_enqueue_scripts', 'ppcp_scripts');
    }

    function ppcp_scripts(){
        wp_register_script('ppcp-smart-button', '/wp-content/plugins/woocommerce-paypal-payments/modules/ppcp-button/assets/js/button.js', true );

        wp_localize_script('ppcp-smart-button','PayPalCommerceGateway', apply_filters( 'PayPalCommerceGateway', localize_script()));

        wp_enqueue_script('ppcp-smart-button');
    } 
}


add_action( 'wp_enqueue_scripts', 'scriptsStripe' );
add_action( 'woocommerce_before_single_product', 'single_page_stripe_js_extra', 999 ); 


function scriptsStripe() {
    if (function_exists('woocommerce_gateway_stripe')){
        if (class_exists('WC_Stripe_Blocks_Support')) {
            $foobar = new WC_Stripe_Blocks_Support;
            $foobar->get_payment_method_data();
        }

        $js_configuration = [];
        $gateways = WC()->payment_gateways->get_available_payment_gateways();
        if ( isset( $gateways['stripe'] ) ) {
            $js_configuration = $gateways['stripe']->javascript_params();
            $js_configuration["is_checkout"] = "yes";
        }

        wp_register_script( 'stripe', 'https://js.stripe.com/v3/', '', '3.0', true );
        wp_register_script( 'wc_stripe_request', '/wp-content/plugins/woocommerce-gateway-stripe/assets/js/stripe.js', true );
        wp_register_script( 'wc_stripe_payment_request', '/wp-content/plugins/woocommerce-gateway-stripe/assets/js/stripe-payment-request.js', true );

        
        wp_localize_script( 'wc_stripe_request', 'wc_stripe_params', apply_filters( 'wc_stripe_params', $js_configuration) );
        wp_localize_script( 'wc_stripe_payment_request', 'wc_stripe_payment_request_params', apply_filters( 'wc_stripe_payment_request_params', $foobar->get_payment_method_data()) );

        wp_enqueue_style( 'ins-strip-card', WP_PLUGIN_URL .'/woocommerce-gateway-stripe/assets/css/stripe-styles.css');
        wp_enqueue_script( 'stripe' );
        wp_enqueue_script( 'wc_stripe_request' );
        wp_enqueue_script( 'wc_stripe_payment_request' );
    }
}

function single_page_stripe_js_extra(){
    wp_dequeue_script('woocommerce_stripe');
}