<?php
/**
 * Cart Page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 7.0.1
 */

defined( 'ABSPATH' ) || exit;

do_action( 'woocommerce_before_cart' ); ?>

<form class="woocommerce-cart-form" action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">
	<?php do_action( 'woocommerce_before_cart_table' ); ?>
	<div class="ins-cart-item-wrap cart woocommerce-cart-form__contents">
		<?php 	
			foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {  

				$_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
				$product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );
				$variation_id = $cart_item['variation_id'];
				if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
					$product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
				?> 
					<div class="ins-single-cart-item woocommerce-cart-form__cart-item <?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>" data-cart-item-key="<?php echo $cart_item_key ?>" data-product-id ="<?php echo $cart_item['product_id'] ?>">
						<div class="ins-cart-item-img product-thumbnail">
							<?php
								$thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );

								if ( ! $product_permalink ) {
									echo $thumbnail; // PHPCS: XSS ok.
								} else {
									printf( '<a href="%s">%s</a>', esc_url( $product_permalink ), $thumbnail ); // PHPCS: XSS ok.
								}
							?>
						</div>
						<div class="ins-cart-item-content">
							<div class="ins-cart-item-title"> 
								<div class="ins-cart-title product-name" data-title="<?php esc_attr_e( 'Product', 'instantio' ); ?>">
									<?php
										if ( ! $product_permalink ) {
											echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key ) . '&nbsp;' );
										} else {
											echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s</a>', esc_url( $product_permalink ), $_product->get_name() ), $cart_item, $cart_item_key ) );
										}

										do_action( 'woocommerce_after_cart_item_name', $cart_item, $cart_item_key );

										// Meta data.
										echo wc_get_formatted_cart_item_data( $cart_item ); // PHPCS: XSS ok.

										// Backorder notification.
										if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
											echo wp_kses_post( apply_filters( 'woocommerce_cart_item_backorder_notification', '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'instantio' ) . '</p>', $product_id ) );
										}
									?>
								</div>
								<!-- <a href="#" class="ins-cart-title">Product Title</a> -->
								<span class="ins-cart-item-price product-subtotal" data-title="<?php esc_attr_e( 'Subtotal', 'instantio' ); ?>">
									<?php
										echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key ); // PHPCS: XSS ok.
									?>
								</span> 
							</div>
							
							<div class="ins-cart-item-quantity product-quantity" data-title="<?php esc_attr_e( 'Quantity', 'instantio' ); ?>">
								<span class="product-price" data-title="<?php esc_attr_e( 'Price', 'instantio' ); ?>">
									<?php
										echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key ); // PHPCS: XSS ok.
									?>
								</span> 
								<div class="ins-cart-qty-wrap"> 
									<?php
									if ( $_product->is_sold_individually() ) {
										$min_quantity = 1;
										$max_quantity = 1;
									} else {
										$min_quantity = 0;
										$max_quantity = $_product->get_max_purchase_quantity();
									}
									$product_quantity = '<button type="button" class="plus ins-cart-plus">+</button>';
									$product_quantity .= woocommerce_quantity_input(
										array(
											'input_name'   => "cart[{$cart_item_key}][qty]",
											'input_value'  => $cart_item['quantity'],
											'max_value'    => $max_quantity,
											'min_value'    => $min_quantity,
											'product_name' => $_product->get_name(),
										),
										$_product,
										false
									);
									$product_quantity .= '<button type="button" class="minus ins-cart-minus">-</button>';

									echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item ); // PHPCS: XSS ok.
								?> 
								</div>
							
								<!-- <span class="ins-cart-plus">+</span>
								<span class="ins-cart-qty"> 1</span>
								<span class="ins-cart-minus">-</span> -->
							</div> 
							<span class="ins-cart-item-remove product-remove">
								<?php
									echo apply_filters( // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
										'woocommerce_cart_item_remove_link',
										sprintf(
											'<a href="%s" class="remove" aria-label="%s" data-product_id="%s" data-product_sku="%s">
												<img class="remove-img" src="'. INS_ASSETS_URL . '/img/delete.png" />
											</a>',
											esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
											esc_html__( 'Remove this item', 'instantio' ),
											esc_attr( $product_id ),
											esc_attr( $variation_id ),
											esc_attr( $_product->get_sku() )
										),
										$cart_item_key
									);
								?>
							</span>
						</div> 
					</div> 
				<?php
			}
		}
		?>
		 
		
		
	</div>
	
	<button class="ins-empty-cart">Empty Cart</button>

	<?php do_action( 'woocommerce_cart_contents' ); ?>
	<div class="ins-cart-coupon">
		<?php if ( wc_coupons_enabled() ) { ?>
			<div class="coupon">
				<!-- <label for="coupon_code"><?php //esc_html_e( 'Coupon:', 'woocommerce' ); ?></label>  -->
				<input type="text" name="coupon_code" class="input-text" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupon code', 'instantio' ); ?>" /> <button type="submit" class="button<?php echo esc_attr( wc_wp_theme_get_element_class_name( 'button' ) ? ' ' . wc_wp_theme_get_element_class_name( 'button' ) : '' ); ?>" name="apply_coupon" value="<?php esc_attr_e( 'Apply coupon', 'instantio' ); ?>"><?php esc_attr_e( 'Apply coupon', 'instantio' ); ?></button>
				<?php do_action( 'woocommerce_cart_coupon' ); ?>
			</div>
		<?php } ?>

		<button type="submit" class="button<?php echo esc_attr( wc_wp_theme_get_element_class_name( 'button' ) ? ' ' . wc_wp_theme_get_element_class_name( 'button' ) : '' ); ?> ins-cart-coupon-updated-cart" name="update_cart" value="<?php esc_attr_e( 'Update cart', 'instantio' ); ?>"><?php esc_html_e( 'Update cart', 'instantio' ); ?></button>

		<?php do_action( 'woocommerce_cart_actions' ); ?>

		<?php wp_nonce_field( 'woocommerce-cart', 'woocommerce-cart-nonce' ); ?>
	</div>

	<?php do_action( 'woocommerce_after_cart_table' ); ?>
</form>
 
<?php do_action( 'woocommerce_before_cart_collaterals' ); ?> 


<div class="ins-cart-totals cart-collaterals">
	<?php 
		 woocommerce_cart_totals(); 
	?>
</div>

<?php // do_action( 'woocommerce_after_cart' ); ?>
